Scopes

Struct Scopes 

pub struct Scopes { /* private fields */ }
An ordered set of resource scopes.

See the module-level documentation for allowed characters, ordering, and the roles scopes play.

Implementations

Source

impl Scopes

pub fn empty() -> Self

Returns an empty set of scopes.

pub fn is_empty(&self) -> bool

Returns true if there are no scopes.

pub fn get(&self, key: &str) -> Option<&Scope>

Returns the scope with the given key, if it exists.

pub fn get_value(&self, key: &str) -> Option<&str>

Returns the value of the scope with the given key, if it exists.

pub fn iter(&self) -> impl Iterator<Item = &Scope>

Returns an iterator over all scopes.

pub fn push<V>(&mut self, key: &str, value: V) -> Result<(), InvalidScopeError>
where V: Display,

Pushes a new scope to the collection.

pub fn as_storage_path(&self) -> AsStoragePath<'_>

Returns a view that formats the scopes as path for storage.

This will serialize the scopes as {name}.{value}/..., which is intended to be used by backends to reference the object in a storage system. This becomes part of the storage path of an ObjectId.

pub fn as_api_path(&self) -> AsApiPath<'_>

Returns a view that formats the scopes as path for web API usage.

This will serialize the scopes as {name}={value};..., which is intended to be used by clients to format URL paths.